
    ############################
    # Robot info
    ############################

    ############################
    # Motion Control
    ############################
    # Default Motion
    # def movej(self, jpos,
    #           blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #           base_type=IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE,
    #           blending_radius=0.0,
    #           vel_ratio=JogVelRatioDefault,
    #           acc_ratio=JogAccRatioDefault):
    #     self._target_pos[0] = 1
    #     if base_type == IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[1] = jpos
    #     else:
    #         self._target_pos[1] = self.get_control_data().q
    #         self._target_pos[1] = list(map(add, self._target_pos[1], jpos))
    #
    #     movejv_dict = dict(jpos=list(jpos),
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius,
    #                        vel=vel_ratio,
    #                        acc=acc_ratio)
    #     result = grpc_mapping_call(self.stub, "AMoveJ", movejv_dict)
    #     return result
    #
    # def movej_time(self, jpos, move_time=2.0,
    #                blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #                base_type=IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE,
    #                blending_radius=0.0):
    #     """
    #     jpos = [deg, deg, deg, deg, deg, deg]
    #     move_time = seconds
    #     """
    #
    #     self._target_pos[0] = 1
    #     if base_type == IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[1] = jpos
    #     else:
    #         self._target_pos[1] = self.get_control_data().q
    #         self._target_pos[1] = list(map(add, self._target_pos[1], jpos))
    #
    #     movejt_dict = dict(jpos=list(jpos),
    #                        time=move_time,
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius)
    #     result = grpc_mapping_call(self.stub, "AMoveJT", movejt_dict)
    #     return result
    #
    # def movel(self, tpos,
    #           blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #           base_type=IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE,
    #           blending_radius=0.0,
    #           vel_ratio=JogVelRatioDefault,
    #           acc_ratio=JogAccRatioDefault):
    #     """
    #     tpos = [mm, mm, mm, deg, deg, deg]
    #     vel_level : 1 ~ 9
    #     """
    #     self._target_pos[0] = 0
    #     if base_type == IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[2] = tpos
    #     else:
    #         self._target_pos[2] = self.get_control_data().p
    #         self._target_pos[2] = self._task_relative_rotation(tpos, self._target_pos[2])
    #
    #     movelv_dict = dict(tpos=list(tpos),
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius,
    #                        vel=vel_ratio,
    #                        acc=acc_ratio)
    #     result = grpc_mapping_call(self.stub, "AMoveL", movelv_dict)
    #     return result
    #
    # def movel_time(self, tpos, move_time=2.0,
    #                blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #                base_type=IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE,
    #                blending_radius=0.0):
    #     """
    #     tpos = [mm, mm, mm, deg, deg, deg]
    #     move_time = seconds
    #     """
    #     self._target_pos[0] = 0
    #     if base_type == IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[2] = tpos
    #     else:
    #         self._target_pos[2] = self.get_control_data().p
    #         self._target_pos[2] = self._task_relative_rotation(tpos, self._target_pos[2])
    #
    #     movelt_dict = dict(tpos=list(tpos),
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius,
    #                        time=move_time)
    #     result = grpc_mapping_call(self.stub, "AMoveLT", movelt_dict)
    #     return result
    #
    # def movec(self, tpos0, tpos1, angle=90.0,
    #           blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #           base_type=IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE,
    #           blending_radius=0.0,
    #           setting_type=IndyClient3CommonMsgs.POINT_SET,
    #           move_type=IndyClient3CommonMsgs.CONSTANT,
    #           vel_ratio=JogVelRatioDefault,
    #           acc_ratio=JogAccRatioDefault):
    #
    #     self._target_pos[0] = 0
    #     if base_type == IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[2] = tpos1
    #     else:
    #         self._target_pos[2] = self.get_control_data().p
    #         self._target_pos[2] = self._task_relative_rotation(tpos1, self._target_pos[2])
    #
    #     movecv_dict = dict(tpos0=list(tpos0),
    #                        tpos1=list(tpos1),
    #                        angle=angle,
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius,
    #                        setting_type=setting_type,
    #                        move_type=move_type,
    #                        vel=vel_ratio,
    #                        acc=acc_ratio)
    #     result = grpc_mapping_call(self.stub, "AMoveC", movecv_dict)
    #     return result
    #
    # def movec_time(self, tpos0, tpos1, angle=90.0,
    #                blending_type=IndyClient3CommonMsgs.BLENDING_TYPE_NONE,
    #                base_type=IndyClient3CommonMsgs.JOINT_BASE_TYPE_ABSOLUTE,
    #                blending_radius=0.0,
    #                setting_type=IndyClient3CommonMsgs.POINT_SET,
    #                move_type=IndyClient3CommonMsgs.CONSTANT,
    #                move_time=2.0):
    #
    #     self._target_pos[0] = 0
    #     if base_type == IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE:
    #         self._target_pos[2] = tpos1
    #     else:
    #         self._target_pos[2] = self._task_relative_rotation(tpos1, self._target_pos[2])
    #
    #     movect_dict = dict(tpos0=list(tpos0),
    #                        tpos1=list(tpos1),
    #                        angle=angle,
    #                        blending_type=blending_type,
    #                        base_type=base_type,
    #                        blending_radius=blending_radius,
    #                        setting_type=setting_type,
    #                        move_type=move_type,
    #                        time=move_time)
    #     result = grpc_mapping_call(self.stub, "AMoveCT", movect_dict)
    #     return result
    #
    # def wait_io(self, di_list, do_list, end_di_list, end_do_list, conjunction=0,
    #             set_do_list=None, set_end_do_list=None, set_ao_list=None, set_end_ao_list=None):
    #     """
    #     do_list = List[Tuple[int, bool]]
    #     di_list = List[Tuple[int, bool]]
    #     """
    #     io_list_dict = dict(
    #         do_list=[{'addr': item.addr, 'on': item.on} for item in do_list],
    #         di_list=[{'addr': item.addr, 'on': item.on} for item in di_list],
    #         end_di_list=[{'addr': item.addr, 'on': item.on} for item in end_di_list],
    #         end_do_list=[{'addr': item.addr, 'on': item.on} for item in end_do_list],
    #         conjunction=conjunction,
    #         set_do_list=[{'addr': item.addr, 'on': item.on} for item in set_do_list],
    #         set_end_do_list=[{'addr': item.addr, 'on': item.on} for item in set_end_do_list],
    #         set_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_ao_list],
    #         set_end_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_end_ao_list]
    #     )
    #     result = grpc_mapping_call(self.stub, "AWaitIO", io_list_dict)
    #     return result
    #
    # def wait_time(self, wait_sec=0,
    #               set_do_list=None, set_end_do_list=None, set_ao_list=None, set_end_ao_list=None):
    #     """
    #     wait_sec = seconds
    #     """
    #     waittime_dict = dict(time=wait_sec,
    #                          set_do_list=[{'addr': item.addr, 'on': item.on} for item in set_do_list],
    #                          set_end_do_list=[{'addr': item.addr, 'on': item.on} for item in set_end_do_list],
    #                          set_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_ao_list],
    #                          set_end_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_end_ao_list])
    #     result = grpc_mapping_call(self.stub, "AWaitTime", waittime_dict)
    #     return result
    #
    # def wait_progress(self, progress=100,
    #                   set_do_list=None, set_end_do_list=None, set_ao_list=None, set_end_ao_list=None):
    #     """
    #     progress = 0 ~ 100%
    #     """
    #     waitprogress_dict = dict(progress=progress,
    #                              set_do_list=[{'addr': item.addr, 'on': item.on} for item in set_do_list],
    #                              set_end_do_list=[{'addr': item.addr, 'on': item.on} for item in set_end_do_list],
    #                              set_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_ao_list],
    #                              set_end_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in
    #                                               set_end_ao_list])
    #     result = grpc_mapping_call(self.stub, "AWaitProgress", waitprogress_dict)
    #     return result
    #
    # def wait_traj(self, traj_condition,
    #               set_do_list=None, set_end_do_list=None, set_ao_list=None, set_end_ao_list=None):
    #     result = grpc_mapping_call(self.stub, "AWaitTraj",
    #                                dict(traj_condition=traj_condition,
    #                                     set_do_list=[{'addr': item.addr, 'on': item.on} for item in set_do_list],
    #                                     set_end_do_list=[{'addr': item.addr, 'on': item.on} for item in
    #                                                      set_end_do_list],
    #                                     set_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in
    #                                                  set_ao_list],
    #                                     set_end_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in
    #                                                      set_end_ao_list]))
    #     return result
    #
    # def wait_radius(self, radius=100,
    #                 set_do_list=None, set_end_do_list=None, set_ao_list=None, set_end_ao_list=None):
    #     """
    #     radius in mm
    #     """
    #     waitradius_dict = dict(radius=radius,
    #                            set_do_list=[{'addr': item.addr, 'on': item.on} for item in set_do_list],
    #                            set_end_do_list=[{'addr': item.addr, 'on': item.on} for item in set_end_do_list],
    #                            set_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in set_ao_list],
    #                            set_end_ao_list=[{'addr': item.addr, 'voltage': item.voltage} for item in
    #                                             set_end_ao_list])
    #     result = grpc_mapping_call(self.stub, "AWaitRadius", waitradius_dict)
    #     return result
    #
    # def move_stop(self):
    #     """
    #     stop move element
    #     """
    #     result = grpc_mapping_call(self.stub, "AMotionStop")
    #     return result
    #
    # # Motion Config
    # def set_ref_frame(self, ref_frame):
    #     result = grpc_mapping_call(self.stub, "SetRefFrame", dict(ref_frame=list(ref_frame)))
    #     return result
    #
    # def set_ref_frame_planar(self, tpos0, tpos1, tpos2):
    #     result = grpc_mapping_call(self.stub, "SetRefFramePlanar", dict(tpos0=list(tpos0),
    #                                                                               tpos1=list(tpos1),
    #                                                                               tpos2=list(tpos2)))
    #     return result
    #
    # def set_tcp_frame(self, tcp_frame):
    #     result = grpc_mapping_call(self.stub, "SetToolFrame", dict(tool_frame=list(tcp_frame)))
    #     return result
    #
    # def set_speed_ratio(self, speed_ratio=50):
    #     """
    #     speed_ratio = 0 ~ 100
    #     """
    #     # print("set_speed_ratio: " + str(speed_ratio))
    #     result = grpc_mapping_call(self.stub, "SetSpeedRatio", dict(ratio=speed_ratio))
    #     return result
    #
    # def set_command_speed_ratio(self, command_speed_ratio=50):
    #     """
    #     command_speed_ratio = 0 ~ 100
    #     """
    #     # print("set_command_speed_ratio: " + str(command_speed_ratio))
    #     result = grpc_mapping_call(self.stub, "SetCommandSpeedRatio", dict(ratio=command_speed_ratio))
    #     return result
    #
    # ############################
    # # Command
    # ############################
    #
    # def reboot(self):
    #     result = grpc_mapping_call(self.stub, "Reboot")
    #     return result
    #
    # def recover(self):
    #     """
    #     Recover from violation
    #     """
    #     result = grpc_mapping_call(self.stub, "Recover")
    #     return result
    #
    # def stop_motion(self, stop_category=IndyClient3CommonMsgs.STOP_CAT_REDUCE_SPEED):
    #     """
    #         STOP_CAT_IMMEDIATE_BRAKE=0;
    #         STOP_CAT_REDUCE_SPEED_AND_BRAKE =1;
    #         STOP_CAT_REDUCE_SPEED=2;
    #     """
    #     result = grpc_mapping_call(self.stub, "Stop", dict(stop_category=stop_category))
    #     return result
    #
    # def pause_motion(self, pause_category=IndyClient3CommonMsgs.PAUSE_CAT_REDUCE_SPEED):
    #     """
    #         PAUSE_CAT_IMMEDIATE=0;
    #         PAUSE_CAT_REDUCE_SPEED=1;
    #     """
    #     result = grpc_mapping_call(self.stub, "Pause", dict(pause_category=pause_category))
    #     return result
    #
    # def resume_motion(self):
    #     result = grpc_mapping_call(self.stub, "Resume")
    #     return result
    #
    # def set_brake(self, on_list: list):
    #     result = grpc_mapping_call(self.stub, "Brake", dict(on_list=list(on_list)))
    #     return result
    #
    # def set_servo(self, on: bool):
    #     result = grpc_mapping_call(self.stub, "Servo", dict(on=on))
    #     return result
    #
    # def set_auto_servooff(self, enable=True, time=20.0):
    #     result = grpc_mapping_call(self.stub, "SetAutoServoOff", dict(enable=enable, time=time))
    #     return result
    #
    # def get_auto_servooff(self):
    #     result = grpc_mapping_call(self.stub, "GetAutoServoOff")
    #     return result
    #
    # def set_simulation_mode(self, on: bool):
    #     result = grpc_mapping_call(self.stub, "SimulationMode", dict(on=on))
    #     return result
    #
    # def set_direct_teaching(self, enable=True):
    #     """
    #     enable = True | False
    #     """
    #     result = grpc_mapping_call(self.stub, "DirectTeachingMode", dict(on=enable))
    #     return result
    #
    # ############################
    # # Data
    # ############################
    #
    # def get_control_data(self):
    #     """
    #     Control Data:
    #         q           -> float[]
    #         qdot        -> float[]
    #         qddot       -> float[]
    #         p           -> float[]
    #         pdot        -> float[]
    #         pddot       -> float[]
    #         ref_frame   -> float[]
    #         tool_frame  -> float[]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetRTControlData")
    #     return result
    #
    # def get_io_data(self):
    #     """
    #     IO Data:
    #         di      -> bool[]
    #         do      -> bool[]
    #         ai      -> int32[]
    #         ao      -> int32[]
    #         end_di  -> bool[]
    #         end_do  -> bool[]
    #         end_ai  -> bool[]
    #         end_ao  -> bool[]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetIOData")
    #     return result
    #
    # def get_core_data(self):
    #     """
    #     CORE Data:
    #         temperatures    -> float[]
    #         voltages        -> float[]
    #         currents        -> float[]
    #         states          -> string[]
    #         state_codes     -> string[]
    #         brake_states    -> bool[]
    #         servo_state     -> bool
    #     """
    #     result = grpc_mapping_call(self.stub, "GetCoreData")
    #     return result
    #
    # def get_system_info(self):
    #     """
    #     System Info:
    #         control_task_ver        -> string
    #         dof                     -> int32
    #         model_name              -> string
    #         robot_sn                -> string
    #         io_board_fw_ver         -> string
    #         core_board_fw_vers[]    -> string[]
    #         endtool_board_fw_ver    -> string
    #         endtool_port_type
    #                                 END_TOOL_PORT_TYPE_A = 0
    #                                 END_TOOL_PORT_TYPE_B = 1
    #                                 END_TOOL_PORT_TYPE_AB = 2
    #     """
    #     result = grpc_mapping_call(self.stub, "GetSystemInfoData")
    #     return result
    #
    # def get_motion_data(self):
    #     """
    #     Motion Info:
    #         traj_progress     -> int32
    #         is_in_motion      -> bool
    #         is_motion_done    -> bool
    #         is_pausing        -> bool
    #         is_stopping        -> bool
    #         has_motion        -> bool
    #         speed_ratio       -> int32
    #         motion_queue_size -> int32
    #         msg               -> string
    #         traj_state
    #                         TRAJSTATE_NONE = 0;
    #                         TRAJSTATE_INIT = 1;
    #                         TRAJSTATE_CALC = 2;
    #                         TRAJSTATE_STBY = 3;
    #                         TRAJSTATE_ACC = 4;
    #                         TRAJSTATE_CRZ = 5;
    #                         TRAJSTATE_DEC = 6;
    #                         TRAJSTATE_FIN = 7;
    #                         TRAJSTATE_CANC = 8;
    #                         TRAJSTATE_ERR = 9;
    #     """
    #     result = grpc_mapping_call(self.stub, "GetMotionData")
    #     return result
    #
    # def get_control_state_data(self):
    #     """
    #     Control State:
    #         violation           -> string
    #         is_simulation_mode  -> bool
    #         state               -> OpState
    #             OP_SYSTEM_OFF=0;
    #             OP_SYSTEM_ON=1;
    #             OP_VIOLATE=2;
    #             OP_RECOVER_HARD=3;
    #             OP_RECOVER_SOFT=4;
    #             OP_IDLE=5;
    #             OP_MOVING=6;
    #             OP_TEACHING=7;
    #             OP_COLLISION=8;
    #             OP_STOP_AND_OFF=9;
    #     """
    #     result = grpc_mapping_call(self.stub, "GetStateData")
    #     return result
    #
    # def get_violation_data(self):
    #     result = grpc_mapping_call(self.stub, "GetViolationData")
    #     return result
    #
    # def set_program_state(self, program_state):
    #     result = grpc_mapping_call(self.stub, "SetProgramState", dict(program_state=program_state))
    #     return result
    #
    # ############################
    # # Utility
    # ############################
    #
    # def calculate_joint_pos(self, tpos, init_jpos):
    #     result = grpc_mapping_call(self.stub, "InverseKinematics", dict(tpos=list(tpos),
    #                                                                               init_jpos=list(init_jpos)))
    #     return result
    #
    # def calculate_relative_pos(self, start_pos, end_pos,
    #                            base_type=IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE):
    #     result = grpc_mapping_call(self.stub, "CalculateRelativePose", dict(start_pos=list(start_pos),
    #                                                                                   end_pos=list(end_pos),
    #                                                                                   base_type=base_type))
    #     return result
    #
    # def calculate_current_pos_rel(self, current_pos, relative_pos,
    #                               base_type=IndyClient3CommonMsgs.TASK_BASE_TYPE_ABSOLUTE):
    #     result = grpc_mapping_call(self.stub, "CalculateCurrentPoseRel",
    #                                dict(current_pos=list(current_pos),
    #                                     relative_pos=list(relative_pos),
    #                                     base_type=base_type))
    #     return result
    #
    # def check_approach_retract_valid(self, tpos, init_jpos, pre_tpos, post_tpos):
    #     for i in range(0, len(pre_tpos)):
    #         pre_tpos[i] = pre_tpos[i] * -1
    #     result = grpc_mapping_call(self.stub, "CheckAproachRetractValid", dict(tpos=list(tpos),
    #                                                                                      init_jpos=list(init_jpos),
    #                                                                                      pre_tpos=list(pre_tpos),
    #                                                                                      post_tpos=list(post_tpos)))
    #     return result
    #
    # def get_pallet_point_list(self, tpos, jpos, pre_tpos, post_tpos, pallet_pattern, width, height):
    #     result = grpc_mapping_call(self.stub, "GetPalletPointList", dict(tpos=list(tpos),
    #                                                                                jpos=list(jpos),
    #                                                                                pre_tpos=list(pre_tpos),
    #                                                                                post_tpos=list(post_tpos),
    #                                                                                pallet_pattern=pallet_pattern,
    #                                                                                width=width,
    #                                                                                height=height))
    #     return result
    #
    # ############################
    # # DIO
    # ############################
    #
    # def set_do(self, do_list: list):
    #     """
    #     do_list = [(int_addr1, True/False), (int_addr1, True/False), ...]
    #     """
    #     do_dict = dict(do_list=[{'addr': item[0], 'on': item[1]} for item in do_list])
    #     result = grpc_mapping_call(self.stub, "SetDO", do_dict)
    #     return result
    #
    # def set_ao(self, ao_list: list):
    #     """
    #     ao_list = [(int_addr1, int), (int_addr1, int), ...]
    #     """
    #     ao_dict = dict(ao_list=[{'addr': item[0], 'voltage': item[1]} for item in ao_list])
    #     result = grpc_mapping_call(self.stub, "SetAO", ao_dict)
    #     return result
    #
    # def set_end_do(self, end_do_list: list):
    #     """
    #     end_do_list = [(int_addr1, True/False), (int_addr1, True/False), ...]
    #     // addr 0 --> 1	//NPN Gripper On
    #     // addr 1 --> 2	//PNP Gripper On
    #     // addr 2 --> 4	//None
    #     // addr 3 --> 8	//EModi Gripper On
    #     """
    #     do_dict = dict(do_list=[{'addr': item[0], 'on': item[1]} for item in end_do_list])
    #     result = grpc_mapping_call(self.stub, "SetEndDO", do_dict)
    #     return result
    #
    # def set_end_ao(self, ao_list: list):
    #     """
    #     ao_list = [(int_addr1, True/False), (int_addr1, True/False), ...]
    #     """
    #     ao_dict = dict(ao_list=[{'addr': item[0], 'voltage': item[1]} for item in ao_list])
    #     result = grpc_mapping_call(self.stub, "SetEndAO", ao_dict)
    #     return result
    #
    # ############################
    # # Config Setting
    # ############################
    #
    # def set_joint_gains(self, kp, kv, kl2):
    #     """
    #     Joint Control Gains:
    #         kp   -> float[6]
    #         kv   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     joint_gains_dict = dict(kp=list(kp), kv=list(kv), kl2=list(kl2))
    #     result = grpc_mapping_call(self.stub, "SetJointControlGain", joint_gains_dict)
    #     return result
    #
    # def get_joint_gains(self):
    #     """
    #     Joint Control Gains:
    #         kp   -> float[6]
    #         kv   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetJointControlGain")
    #     return result
    #
    # def set_task_gains(self, kp, kv, kl2):
    #     """
    #     Task Control Gains:
    #         kp   -> float[6]
    #         kv   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     task_gains_dict = dict(kp=list(kp), kv=list(kv), kl2=list(kl2))
    #     result = grpc_mapping_call(self.stub, "SetTaskControlGain", task_gains_dict)
    #     return result
    #
    # def get_task_gains(self):
    #     """
    #     Task Control Gains:
    #         kp   -> float[6]
    #         kv   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetTaskControlGain")
    #     return result
    #
    # def set_impedance_gains(self, mass, damping, stiffness, kl2):
    #     """
    #     Impedance Control Gains:
    #         mass   -> float[6]
    #         damping   -> float[6]
    #         stiffness   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     impedance_gains_dict = dict(mass=list(mass), damping=list(damping), stiffness=list(stiffness), kl2=list(kl2))
    #     result = grpc_mapping_call(self.stub, "SetImpedanceControlGain", impedance_gains_dict)
    #     return result
    #
    # def get_impedance_gains(self):
    #     """
    #     Impedance Control Gains:
    #         mass   -> float[6]
    #         damping   -> float[6]
    #         stiffness   -> float[6]
    #         kl2  -> float[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetImpedanceControlGain")
    #     return result
    #
    # def set_mounting_angles(self, rotY, rotZ):
    #     """
    #     Mounting Angles:
    #         rotY                -> double
    #         rotZ                -> double
    #     """
    #     result = grpc_mapping_call(self.stub, "SetMountPos", dict(ry=rotY, rz=rotZ))
    #     return result
    #
    # def get_mounting_angles(self):
    #     """
    #     Mounting Angles:
    #         rotY                -> double
    #         rotZ                -> double
    #     """
    #     result = grpc_mapping_call(self.stub, "GetMountPos")
    #     return result
    #
    # def set_tool_property(self, mass, center_of_mass, inertia):
    #     """
    #     Tool Property:
    #         mass                -> double
    #         center_of_mass      -> double[3]
    #         inertia             -> double[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "SetToolProperty", dict(mass=mass,
    #                                                                             center_of_mass=list(center_of_mass),
    #                                                                             inertia=list(inertia)))
    #     return result
    #
    # def get_tool_property(self):
    #     """
    #     Tool Property:
    #         mass                -> double
    #         center_of_mass      -> double[3]
    #         inertia             -> double[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetToolProperty")
    #     return result
    #
    # def set_collision_level(self, level):
    #     """
    #     Collision Level: 1 ~ 5
    #     """
    #     result = grpc_mapping_call(self.stub, "SetCollSensLevel", dict(level=level))
    #     return result
    #
    # def get_collision_level(self):
    #     """
    #     Collision Level: 1 ~ 5
    #     """
    #     result = grpc_mapping_call(self.stub, "GetCollSensLevel")
    #     return result
    #
    # def set_collision_params(self, j_torque_bases, j_torque_tangents,
    #                          t_torque_bases, t_torque_tangents,
    #                          t_constvel_torque_bases, t_constvel_torque_tangents,
    #                          t_conveyor_torque_bases, t_conveyor_torque_tangents,
    #                          error_bases, error_tangents):
    #     """
    #     Collision Params:
    #         j_torque_bases                  -> double[6]
    #         j_torque_tangents               -> double[6]
    #         t_torque_bases                  -> double[6]
    #         t_torque_tangents               -> double[6]
    #         t_constvel_torque_bases         -> double[6]
    #         t_constvel_torque_tangents      -> double[6]
    #         t_conveyor_torque_bases         -> double[6]
    #         t_conveyor_torque_tangents      -> double[6]
    #         error_bases                     -> double[6]
    #         error_tangents                  -> double[6]
    #     """
    #     collision_params_dict = dict(j_torque_bases=list(j_torque_bases), j_torque_tangents=list(j_torque_tangents),
    #                                  t_torque_bases=list(t_torque_bases), t_torque_tangents=list(t_torque_tangents),
    #                                  t_constvel_torque_bases=list(t_constvel_torque_bases),
    #                                  t_constvel_torque_tangents=list(t_constvel_torque_tangents),
    #                                  t_conveyor_torque_bases=list(t_conveyor_torque_bases),
    #                                  t_conveyor_torque_tangents=list(t_conveyor_torque_tangents),
    #                                  error_bases=list(error_bases), error_tangents=list(error_tangents))
    #     result = grpc_mapping_call(self.stub, "SetCollSensParam", collision_params_dict)
    #     return result
    #
    # def get_collision_params(self):
    #     """
    #     Collision Params:
    #         j_torque_bases                  -> double[6]
    #         j_torque_tangents               -> double[6]
    #         t_torque_bases                  -> double[6]
    #         t_torque_tangents               -> double[6]
    #         t_constvel_torque_bases         -> double[6]
    #         t_constvel_torque_tangents      -> double[6]
    #         t_conveyor_torque_bases         -> double[6]
    #         t_conveyor_torque_tangents      -> double[6]
    #         error_bases                     -> double[6]
    #         error_tangents                  -> double[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetCollSensParam")
    #     for i in range(0, 6):
    #         result.j_torque_bases[i] = round(result.j_torque_bases[i], 4)
    #         result.j_torque_tangents[i] = round(result.j_torque_tangents[i], 4)
    #         result.t_torque_bases[i] = round(result.t_torque_bases[i], 4)
    #         result.t_torque_tangents[i] = round(result.t_torque_tangents[i], 4)
    #         result.t_constvel_torque_bases[i] = round(result.t_constvel_torque_bases[i], 4)
    #         result.t_constvel_torque_tangents[i] = round(result.t_constvel_torque_tangents[i], 4)
    #         result.t_conveyor_torque_bases[i] = round(result.t_conveyor_torque_bases[i], 4)
    #         result.t_conveyor_torque_tangents[i] = round(result.t_conveyor_torque_tangents[i], 4)
    #         result.error_bases[i] = round(result.error_bases[i], 4)
    #         result.error_tangents[i] = round(result.error_tangents[i], 4)
    #     return result
    #
    # def set_collision_policy(self, policy=IndyClient3CommonMsgs.COLLISION_POLICY_STOP, sleep_time=0, gravity_time=0.1):
    #     """
    #     Collision Policy:
    #        policy      -> NO_DETECT | PAUSE | RESUME_AFTER_SLEEP | STOP
    #        sleep_time  -> float (sec)
    #     """
    #     result = grpc_mapping_call(self.stub, "SetCollPolicy",
    #                                dict(policy=policy, sleep_time=sleep_time, gravity_time=gravity_time))
    #     return result
    #
    # def get_collision_policy(self):
    #     """
    #     Collision Policy:
    #        policy      -> NO_DETECT | PAUSE | RESUME_AFTER_SLEEP | STOP
    #        sleep_time  -> float (sec)
    #        gravity_time  -> float (sec)
    #     """
    #     result = grpc_mapping_call(self.stub, "GetCollPolicy")
    #     return result
    #
    # def get_collision_tuning_params(self):
    #     """
    #     Collision Params:
    #         j_torque_bases                  -> double[6]
    #         j_torque_tangents               -> double[6]
    #         t_torque_bases                  -> double[6]
    #         t_torque_tangents               -> double[6]
    #         t_constvel_torque_bases         -> double[6]
    #         t_constvel_torque_tangents      -> double[6]
    #         t_conveyor_torque_bases         -> double[6]
    #         t_conveyor_torque_tangents      -> double[6]
    #         error_bases                     -> double[6]
    #         error_tangents                  -> double[6]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetCollTuningParam")
    #     for i in range(0, 6):
    #         result.j_torque_bases[i] = round(result.j_torque_bases[i], 4)
    #         result.j_torque_tangents[i] = round(result.j_torque_tangents[i], 4)
    #         result.t_torque_bases[i] = round(result.t_torque_bases[i], 4)
    #         result.t_torque_tangents[i] = round(result.t_torque_tangents[i], 4)
    #         result.t_constvel_torque_bases[i] = round(result.t_constvel_torque_bases[i], 4)
    #         result.t_constvel_torque_tangents[i] = round(result.t_constvel_torque_tangents[i], 4)
    #         result.t_conveyor_torque_bases[i] = round(result.t_conveyor_torque_bases[i], 4)
    #         result.t_conveyor_torque_tangents[i] = round(result.t_conveyor_torque_tangents[i], 4)
    #         result.error_bases[i] = round(result.error_bases[i], 4)
    #         result.error_tangents[i] = round(result.error_tangents[i], 4)
    #     return result
    #
    # def set_friction_comp_level(self, control_comp: bool, control_comp_levels: list,
    #                             dt_comp: bool, dt_comp_levels: list,
    #                             id_joint=-1):
    #     friction_comp_level_dict = dict(control_comp=control_comp, control_comp_levels=list(control_comp_levels),
    #                                     dt_comp=dt_comp, dt_comp_levels=list(dt_comp_levels),
    #                                     id_joint=id_joint)
    #     result = grpc_mapping_call(self.stub, "SetFricComp", friction_comp_level_dict)
    #     return result
    #
    # def get_friction_comp_level(self):
    #     result = grpc_mapping_call(self.stub, "GetFricComp")
    #     return result
    #
    # def set_safety_limit(self, power_limit: float, power_limit_ratio: float,
    #                      tcp_force_limit: float, tcp_force_limit_ratio: float,
    #                      tcp_speed_limit: float, tcp_speed_limit_ratio: float, ):
    #     """
    #     Safety Limits:
    #         power_limit             -> float
    #         power_limit_ratio       -> float
    #         tcp_force_limit         -> float
    #         tcp_force_limit_ratio   -> float
    #         tcp_speed_limit         -> float
    #         tcp_speed_limit_ratio   -> float
    #         joint_limits   -> float[]
    #     """
    #     safety_limit_dict = dict(power_limit=power_limit,
    #                              power_limit_ratio=power_limit_ratio,
    #                              tcp_force_limit=tcp_force_limit,
    #                              tcp_force_limit_ratio=tcp_force_limit_ratio,
    #                              tcp_speed_limit=tcp_speed_limit,
    #                              tcp_speed_limit_ratio=tcp_speed_limit_ratio,
    #                              joint_limits=[179, 179, 179, 179, 179, 179])  # Joint Limits is not applied yet
    #     result = grpc_mapping_call(self.stub, "SetSafetyLimitConfig", safety_limit_dict)
    #     return result
    #
    # def get_safety_limit(self):
    #     """
    #     Safety Limits:
    #         power_limit             -> float
    #         power_limit_ratio       -> float
    #         tcp_force_limit         -> float
    #         tcp_force_limit_ratio   -> float
    #         tcp_speed_limit         -> float
    #         tcp_speed_limit_ratio   -> float
    #         joint_limits   -> float[]
    #     """
    #     result = grpc_mapping_call(self.stub, "GetSafetyLimitConfig")
    #     return result
    #
    # def set_safety_stop_cat(self, jpos_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE,
    #                         jvel_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE,
    #                         jtau_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE,
    #                         tvel_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE,
    #                         tforce_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE,
    #                         power_limit_stop=IndyClient3CommonMsgs.STOP_CAT_IMMEDIATE_BRAKE):
    #     """
    #     Safety Stop Category:
    #         jpos_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         jvel_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         jtau_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         tvel_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         tforce_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         power_limit_stop = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #     """
    #     safety_stop_dict = dict(joint_position_limit_stop_cat=jpos_limit_stop,
    #                             joint_speed_limit_stop_cat=jvel_limit_stop,
    #                             joint_torque_limit_stop_cat=jtau_limit_stop,
    #                             tcp_speed_limit_stop_cat=tvel_limit_stop,
    #                             tcp_force_limit_stop_cat=tforce_limit_stop,
    #                             power_limit_stop_cat=power_limit_stop)
    #     result = grpc_mapping_call(self.stub, "SetSafetyStopConfig", safety_stop_dict)
    #     return result
    #
    # def get_safety_stop_cat(self):
    #     """
    #     Safety Stop Category:
    #         joint_position_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         joint_speed_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         joint_torque_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         tcp_speed_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         tcp_force_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #         power_limit_stop_cat = IMMEDIATE_BRAKE(0) | REDUCE_SPEED_AND_BRAKE(1) | REDUCE_SPEED(2)
    #     """
    #     result = grpc_mapping_call(self.stub, "GetSafetyStopConfig")
    #     return result
    #
    # @staticmethod
    # def _rotation_matrix(rpy):
    #     roll_rad = rpy[0] * math.pi / 180
    #     pitch_rad = rpy[1] * math.pi / 180
    #     yaw_rad = rpy[2] * math.pi / 180
    #     a = math.cos(pitch_rad) * math.cos(yaw_rad)
    #     b = math.sin(roll_rad) * math.sin(pitch_rad) * math.cos(yaw_rad) - math.cos(roll_rad) * math.sin(yaw_rad)
    #     c = math.cos(roll_rad) * math.sin(pitch_rad) * math.cos(yaw_rad) + math.sin(roll_rad) * math.sin(yaw_rad)
    #     e = math.cos(pitch_rad) * math.sin(yaw_rad)
    #     f = math.sin(roll_rad) * math.sin(pitch_rad) * math.sin(yaw_rad) + math.cos(roll_rad) * math.cos(yaw_rad)
    #     g = math.cos(roll_rad) * math.sin(pitch_rad) * math.sin(yaw_rad) - math.sin(roll_rad) * math.cos(yaw_rad)
    #     i = -math.sin(pitch_rad)
    #     j = math.sin(roll_rad) * math.cos(pitch_rad)
    #     k = math.cos(roll_rad) * math.cos(pitch_rad)
    #     return [[a, b, c], [e, f, g], [i, j, k]]
    #
    # def _task_relative_rotation(self, tpos, current):
    #     _rot_c = self._rotation_matrix(current[3:])
    #     _rot_t = self._rotation_matrix(tpos[3:])
    #     e = [_rot_t[0][0] * _rot_c[0][0] + _rot_t[0][1] * _rot_c[1][0] + _rot_t[0][2] * _rot_c[2][0],
    #          _rot_t[1][0] * _rot_c[0][0] + _rot_t[1][1] * _rot_c[1][0] + _rot_t[1][2] * _rot_c[2][0],
    #          _rot_t[2][0] * _rot_c[0][0] + _rot_t[2][1] * _rot_c[1][0] + _rot_t[2][2] * _rot_c[2][0],
    #          _rot_t[2][0] * _rot_c[0][1] + _rot_t[2][1] * _rot_c[1][1] + _rot_t[2][2] * _rot_c[2][1],
    #          _rot_t[2][0] * _rot_c[0][2] + _rot_t[2][1] * _rot_c[1][2] + _rot_t[2][2] * _rot_c[2][2]]
    #     x = current[0] + tpos[0]
    #     y = current[1] + tpos[1]
    #     z = current[2] + tpos[2]
    #     u = math.atan2(e[3], e[4]) * 180 / math.pi
    #     v = -math.asin(e[2]) * 180 / math.pi
    #     w = math.atan2(e[1], e[0]) * 180 / math.pi
    #     return [x, y, z, u, v, w]



NONE = 0

SW_VIOLATION = 0x01
SW_JPOS_FOLLOW_ERROR = SW_VIOLATION << 0
SW_JPOS_LIMIT_CLOSED = SW_VIOLATION << 1
SW_JVEL_LIMIT_CLOSED = SW_VIOLATION << 2
SW_JACC_LIMIT_CLOSED = SW_VIOLATION << 3
SW_JTAU_LIMIT_CLOSED = SW_VIOLATION << 4
SW_TCP_SINGULAR_REACHED = SW_VIOLATION << 5
SW_TCP_SINGULAR_CLOSED = SW_VIOLATION << 6

ISO_VIOLATION = SW_VIOLATION << 7
ISO_JPOS_LIMIT = ISO_VIOLATION << 0
ISO_JVEL_LIMIT = ISO_VIOLATION << 1
ISO_JTAU_LIMIT = ISO_VIOLATION << 2
ISO_TCP_VEL_LIMIT = ISO_VIOLATION << 3
ISO_TCP_FORCE_LIMIT = ISO_VIOLATION << 4
ISO_POWER_LIMIT = ISO_VIOLATION << 5
ISO_STANDSTILL_FAILED = ISO_VIOLATION << 6
ISO_CONTY_LOSS_COMM = ISO_VIOLATION << 7
ISO_INDYKEY_LOSS_COMM = ISO_VIOLATION << 8
ISO_SAFETY_GUARD_IN1 = ISO_VIOLATION << 9
ISO_SAFETY_GUARD_IN2 = ISO_VIOLATION << 10
ISO_EMERGENCY_BUTTON = ISO_VIOLATION << 11

HW_VIOLATION = ISO_VIOLATION << 12
HW_ROBOTSPECS_ERROR = HW_VIOLATION << 0
HW_CONNECTION_LOST = HW_VIOLATION << 1
HW_MOTOR_STATUS_ERROR = HW_VIOLATION << 2
HW_MOTOR_OVERCURRENT = HW_VIOLATION << 3
HW_MOTOR_OVERHEATED = HW_VIOLATION << 4
HW_MOTOR_ERROR_BIT = HW_VIOLATION << 5
HW_MOTOR_LOW_BATTERY = HW_VIOLATION << 6
HW_MOTOR_FIRMWARE_ERROR = HW_VIOLATION << 7

RT_TASK_TIME_LIMIT = HW_VIOLATION << 8
SOFT_RECOVERY_FAILED = HW_VIOLATION << 9

EXTRA_VIOLATION = HW_VIOLATION << 10
AUTO_SERVO_OFF = EXTRA_VIOLATION << 0
TELE_STARTING_TOO_FAR = EXTRA_VIOLATION << 1


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethercat_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ethercat_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x65thercat_msgs.proto\x12\x12Nrmk.IndyFramework\"\x1e\n\x0cMasterStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\"\x1d\n\x0bSlaveStatus\x12\x0e\n\x06status\x18\x01 \x03(\r\"\"\n\x10\x45\x63\x61tDomainStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\" \n\x0f\x45\x63\x61tSystemReady\x12\r\n\x05ready\x18\x01 \x03(\x08\"\x1c\n\x0b\x45\x63\x61tServoOn\x12\r\n\x05servo\x18\x01 \x03(\x08\"\\\n\x0cSlaveTypeNum\x12\x11\n\tnum_servo\x18\x01 \x01(\r\x12\x13\n\x0bnum_ioboard\x18\x02 \x01(\r\x12\x13\n\x0bnum_endtool\x18\x03 \x01(\r\x12\x0f\n\x07num_dio\x18\x04 \x01(\r\" \n\nServoIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\"\x1e\n\tEcatIndex\x12\x11\n\tecatIndex\x18\x01 \x01(\r\"w\n\x07ServoTx\x12\x12\n\nstatusWord\x18\x01 \x01(\r\x12\x12\n\nmodeOpDisp\x18\x02 \x01(\x05\x12\x16\n\x0e\x61\x63tualPosition\x18\x03 \x01(\x05\x12\x16\n\x0e\x61\x63tualVelocity\x18\x04 \x01(\x05\x12\x14\n\x0c\x61\x63tualTorque\x18\x05 \x01(\x05\"t\n\x07ServoRx\x12\x13\n\x0b\x63ontrolWord\x18\x01 \x01(\r\x12\x0e\n\x06modeOp\x18\x02 \x01(\x05\x12\x16\n\x0etargetPosition\x18\x03 \x01(\x03\x12\x16\n\x0etargetVelocity\x18\x04 \x01(\x05\x12\x14\n\x0ctargetTorque\x18\x05 \x01(\x05\"K\n\x0cServoTxIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12\'\n\x02tx\x18\x02 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.ServoTx\"K\n\x0cServoRxIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12\'\n\x02rx\x18\x02 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.ServoRx\"\xdf\x01\n\x0bServoTxKeba\x12\x12\n\nstatusWord\x18\x01 \x01(\r\x12\x13\n\x0bstatusWord2\x18\x02 \x01(\r\x12\x13\n\x0bstatusWord3\x18\x03 \x01(\r\x12\x16\n\x0e\x61\x63tualPosition\x18\x04 \x01(\x05\x12\x17\n\x0f\x61\x63tualPosition2\x18\x05 \x01(\x05\x12\x17\n\x0f\x61\x63tualPosition3\x18\x06 \x01(\x05\x12\x16\n\x0e\x61\x63tualVelocity\x18\x07 \x01(\x05\x12\x17\n\x0f\x61\x63tualVelocity2\x18\x08 \x01(\x05\x12\x17\n\x0f\x61\x63tualVelocity3\x18\t \x01(\x05\"\xdc\x01\n\x0bServoRxKeba\x12\x13\n\x0b\x63ontrolWord\x18\x01 \x01(\r\x12\x14\n\x0c\x63ontrolWord2\x18\x02 \x01(\r\x12\x14\n\x0c\x63ontrolWord3\x18\x03 \x01(\r\x12\x16\n\x0etargetPosition\x18\x04 \x01(\x03\x12\x17\n\x0ftargetPosition2\x18\x05 \x01(\x03\x12\x17\n\x0ftargetPosition3\x18\x06 \x01(\x03\x12\x14\n\x0ctargetTorque\x18\x07 \x01(\x05\x12\x15\n\rtargetTorque2\x18\x08 \x01(\x05\x12\x15\n\rtargetTorque3\x18\t \x01(\x05\"S\n\x10ServoRxIndexKeba\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12+\n\x02rx\x18\x02 \x01(\x0b\x32\x1f.Nrmk.IndyFramework.ServoRxKeba\" \n\tServoTemp\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"\x1f\n\nServoError\x12\x11\n\terrorCode\x18\x01 \x01(\r\".\n\nServoBrake\x12\x11\n\tecatIndex\x18\x01 \x01(\r\x12\r\n\x05onoff\x18\x02 \x01(\x08\"R\n\x08\x46TSensor\x12\n\n\x02\x66x\x18\x01 \x01(\x05\x12\n\n\x02\x66y\x18\x02 \x01(\x05\x12\n\n\x02\x66z\x18\x03 \x01(\x05\x12\n\n\x02tx\x18\x04 \x01(\x05\x12\n\n\x02ty\x18\x05 \x01(\x05\x12\n\n\x02tz\x18\x06 \x01(\x05\"\x80\x01\n\tEndtoolTx\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x0e\n\x06\x62utton\x18\x02 \x01(\r\x12/\n\tft_sensor\x18\x03 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.FTSensor\x12\x10\n\x08\x66t_state\x18\x04 \x01(\r\x12\x10\n\x08\x66t_error\x18\x05 \x01(\r\"z\n\tEndtoolRx\x12\x0b\n\x03\x65qc\x18\x01 \x01(\r\x12\x0f\n\x07gripper\x18\x02 \x01(\r\x12\x10\n\x08\x66t_param\x18\x03 \x01(\r\x12\x10\n\x08led_mode\x18\x04 \x01(\r\x12\r\n\x05led_g\x18\x05 \x01(\r\x12\r\n\x05led_r\x18\x06 \x01(\r\x12\r\n\x05led_b\x18\x07 \x01(\r\"\x8c\x03\n\x10\x45ndtoolDockingTx\x12\x16\n\x0e\x64ocking_status\x18\x01 \x01(\r\x12\x16\n\x0e\x64ocking_button\x18\x02 \x01(\r\x12\x15\n\rdocking_dist1\x18\x03 \x01(\r\x12\x15\n\rdocking_dist2\x18\x04 \x01(\r\x12\x15\n\rdocking_dist3\x18\x05 \x01(\r\x12\x15\n\rdocking_dist4\x18\x06 \x01(\r\x12\x15\n\rdocking_dist5\x18\x07 \x01(\r\x12\x15\n\rdocking_dist6\x18\x08 \x01(\r\x12\x15\n\rdocking_dist7\x18\t \x01(\r\x12\x15\n\rdocking_dist8\x18\n \x01(\r\x12\x15\n\rdirect_status\x18\x0b \x01(\r\x12\x15\n\rdirect_button\x18\x0c \x01(\r\x12\x16\n\x0e\x64irect_encoder\x18\r \x01(\r\x12\x11\n\tjoystic1x\x18\x0e \x01(\r\x12\x11\n\tjoystic1y\x18\x0f \x01(\r\x12\x11\n\tjoystic2x\x18\x10 \x01(\r\x12\x11\n\tjoystic2y\x18\x11 \x01(\r\"\x84\x01\n\tIOBoardTx\x12\x0c\n\x04\x64i5v\x18\x01 \x01(\r\x12\x0e\n\x06\x64i24v1\x18\x02 \x01(\r\x12\x0e\n\x06\x64i24v2\x18\x03 \x01(\r\x12\x0b\n\x03\x61i1\x18\x04 \x01(\r\x12\x0b\n\x03\x61i2\x18\x05 \x01(\r\x12/\n\tft_sensor\x18\x06 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.FTSensor\"e\n\tIOBoardRx\x12\x0c\n\x04\x64o5v\x18\x01 \x01(\r\x12\x0e\n\x06\x64o24v1\x18\x02 \x01(\r\x12\x0e\n\x06\x64o24v2\x18\x03 \x01(\r\x12\x0b\n\x03\x61o1\x18\x04 \x01(\r\x12\x0b\n\x03\x61o2\x18\x05 \x01(\r\x12\x10\n\x08\x66t_param\x18\x06 \x01(\r\"\x1c\n\x08\x44IOIndex\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\"4\n\x0f\x44IODigitalInput\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\x12\x0f\n\x07\x64i_list\x18\x02 \x03(\r\"5\n\x10\x44IODigitalOutput\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\x12\x0f\n\x07\x64o_list\x18\x02 \x03(\r\"+\n\nServoParam\x12\x10\n\x08slaveIdx\x18\x01 \x01(\r\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\x18\n\tSDOIntVal\x12\x0b\n\x03val\x18\x01 \x01(\x05\"\x1a\n\x0bSDOFloatVal\x12\x0b\n\x03val\x18\x01 \x01(\x02\"\x18\n\tSDOStrVal\x12\x0b\n\x03val\x18\x01 \x01(\t\"\x0e\n\x0c\x45therCATInfo\"\x1f\n\x0eRobotZeroCount\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x62\x06proto3'
)




_MASTERSTATUS = _descriptor.Descriptor(
  name='MasterStatus',
  full_name='Nrmk.IndyFramework.MasterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.MasterStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=73,
)


_SLAVESTATUS = _descriptor.Descriptor(
  name='SlaveStatus',
  full_name='Nrmk.IndyFramework.SlaveStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.SlaveStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=104,
)


_ECATDOMAINSTATUS = _descriptor.Descriptor(
  name='EcatDomainStatus',
  full_name='Nrmk.IndyFramework.EcatDomainStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.EcatDomainStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=140,
)


_ECATSYSTEMREADY = _descriptor.Descriptor(
  name='EcatSystemReady',
  full_name='Nrmk.IndyFramework.EcatSystemReady',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ready', full_name='Nrmk.IndyFramework.EcatSystemReady.ready', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=174,
)


_ECATSERVOON = _descriptor.Descriptor(
  name='EcatServoOn',
  full_name='Nrmk.IndyFramework.EcatServoOn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servo', full_name='Nrmk.IndyFramework.EcatServoOn.servo', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=204,
)


_SLAVETYPENUM = _descriptor.Descriptor(
  name='SlaveTypeNum',
  full_name='Nrmk.IndyFramework.SlaveTypeNum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_servo', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_servo', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ioboard', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_ioboard', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_endtool', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_endtool', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_dio', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_dio', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=298,
)


_SERVOINDEX = _descriptor.Descriptor(
  name='ServoIndex',
  full_name='Nrmk.IndyFramework.ServoIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=332,
)


_ECATINDEX = _descriptor.Descriptor(
  name='EcatIndex',
  full_name='Nrmk.IndyFramework.EcatIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ecatIndex', full_name='Nrmk.IndyFramework.EcatIndex.ecatIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=364,
)


_SERVOTX = _descriptor.Descriptor(
  name='ServoTx',
  full_name='Nrmk.IndyFramework.ServoTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusWord', full_name='Nrmk.IndyFramework.ServoTx.statusWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOpDisp', full_name='Nrmk.IndyFramework.ServoTx.modeOpDisp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition', full_name='Nrmk.IndyFramework.ServoTx.actualPosition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity', full_name='Nrmk.IndyFramework.ServoTx.actualVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTorque', full_name='Nrmk.IndyFramework.ServoTx.actualTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=485,
)


_SERVORX = _descriptor.Descriptor(
  name='ServoRx',
  full_name='Nrmk.IndyFramework.ServoRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlWord', full_name='Nrmk.IndyFramework.ServoRx.controlWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOp', full_name='Nrmk.IndyFramework.ServoRx.modeOp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition', full_name='Nrmk.IndyFramework.ServoRx.targetPosition', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetVelocity', full_name='Nrmk.IndyFramework.ServoRx.targetVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='Nrmk.IndyFramework.ServoRx.targetTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=603,
)


_SERVOTXINDEX = _descriptor.Descriptor(
  name='ServoTxIndex',
  full_name='Nrmk.IndyFramework.ServoTxIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoTxIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='Nrmk.IndyFramework.ServoTxIndex.tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=680,
)


_SERVORXINDEX = _descriptor.Descriptor(
  name='ServoRxIndex',
  full_name='Nrmk.IndyFramework.ServoRxIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoRxIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='Nrmk.IndyFramework.ServoRxIndex.rx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=757,
)


_SERVOTXKEBA = _descriptor.Descriptor(
  name='ServoTxKeba',
  full_name='Nrmk.IndyFramework.ServoTxKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusWord', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusWord2', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusWord3', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord3', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition2', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition3', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition3', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity2', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity2', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity3', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity3', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=983,
)


_SERVORXKEBA = _descriptor.Descriptor(
  name='ServoRxKeba',
  full_name='Nrmk.IndyFramework.ServoRxKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlWord', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controlWord2', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controlWord3', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord3', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition2', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition2', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition3', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition3', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque2', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque2', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque3', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque3', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1206,
)


_SERVORXINDEXKEBA = _descriptor.Descriptor(
  name='ServoRxIndexKeba',
  full_name='Nrmk.IndyFramework.ServoRxIndexKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoRxIndexKeba.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='Nrmk.IndyFramework.ServoRxIndexKeba.rx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1291,
)


_SERVOTEMP = _descriptor.Descriptor(
  name='ServoTemp',
  full_name='Nrmk.IndyFramework.ServoTemp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='temperature', full_name='Nrmk.IndyFramework.ServoTemp.temperature', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1325,
)


_SERVOERROR = _descriptor.Descriptor(
  name='ServoError',
  full_name='Nrmk.IndyFramework.ServoError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorCode', full_name='Nrmk.IndyFramework.ServoError.errorCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1358,
)


_SERVOBRAKE = _descriptor.Descriptor(
  name='ServoBrake',
  full_name='Nrmk.IndyFramework.ServoBrake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ecatIndex', full_name='Nrmk.IndyFramework.ServoBrake.ecatIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onoff', full_name='Nrmk.IndyFramework.ServoBrake.onoff', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1406,
)


_FTSENSOR = _descriptor.Descriptor(
  name='FTSensor',
  full_name='Nrmk.IndyFramework.FTSensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fx', full_name='Nrmk.IndyFramework.FTSensor.fx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fy', full_name='Nrmk.IndyFramework.FTSensor.fy', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fz', full_name='Nrmk.IndyFramework.FTSensor.fz', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='Nrmk.IndyFramework.FTSensor.tx', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ty', full_name='Nrmk.IndyFramework.FTSensor.ty', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tz', full_name='Nrmk.IndyFramework.FTSensor.tz', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1490,
)


_ENDTOOLTX = _descriptor.Descriptor(
  name='EndtoolTx',
  full_name='Nrmk.IndyFramework.EndtoolTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.EndtoolTx.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Nrmk.IndyFramework.EndtoolTx.button', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_sensor', full_name='Nrmk.IndyFramework.EndtoolTx.ft_sensor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_state', full_name='Nrmk.IndyFramework.EndtoolTx.ft_state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_error', full_name='Nrmk.IndyFramework.EndtoolTx.ft_error', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1621,
)


_ENDTOOLRX = _descriptor.Descriptor(
  name='EndtoolRx',
  full_name='Nrmk.IndyFramework.EndtoolRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eqc', full_name='Nrmk.IndyFramework.EndtoolRx.eqc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gripper', full_name='Nrmk.IndyFramework.EndtoolRx.gripper', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_param', full_name='Nrmk.IndyFramework.EndtoolRx.ft_param', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_mode', full_name='Nrmk.IndyFramework.EndtoolRx.led_mode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_g', full_name='Nrmk.IndyFramework.EndtoolRx.led_g', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_r', full_name='Nrmk.IndyFramework.EndtoolRx.led_r', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_b', full_name='Nrmk.IndyFramework.EndtoolRx.led_b', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1623,
  serialized_end=1745,
)


_ENDTOOLDOCKINGTX = _descriptor.Descriptor(
  name='EndtoolDockingTx',
  full_name='Nrmk.IndyFramework.EndtoolDockingTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='docking_status', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_button', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_button', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist1', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist2', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist3', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist3', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist4', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist4', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist5', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist5', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist6', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist6', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist7', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist7', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist8', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist8', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_status', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_status', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_button', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_button', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_encoder', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_encoder', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic1x', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic1x', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic1y', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic1y', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic2x', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic2x', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic2y', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic2y', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1748,
  serialized_end=2144,
)


_IOBOARDTX = _descriptor.Descriptor(
  name='IOBoardTx',
  full_name='Nrmk.IndyFramework.IOBoardTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di5v', full_name='Nrmk.IndyFramework.IOBoardTx.di5v', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di24v1', full_name='Nrmk.IndyFramework.IOBoardTx.di24v1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di24v2', full_name='Nrmk.IndyFramework.IOBoardTx.di24v2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai1', full_name='Nrmk.IndyFramework.IOBoardTx.ai1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai2', full_name='Nrmk.IndyFramework.IOBoardTx.ai2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_sensor', full_name='Nrmk.IndyFramework.IOBoardTx.ft_sensor', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2279,
)


_IOBOARDRX = _descriptor.Descriptor(
  name='IOBoardRx',
  full_name='Nrmk.IndyFramework.IOBoardRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='do5v', full_name='Nrmk.IndyFramework.IOBoardRx.do5v', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do24v1', full_name='Nrmk.IndyFramework.IOBoardRx.do24v1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do24v2', full_name='Nrmk.IndyFramework.IOBoardRx.do24v2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao1', full_name='Nrmk.IndyFramework.IOBoardRx.ao1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao2', full_name='Nrmk.IndyFramework.IOBoardRx.ao2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_param', full_name='Nrmk.IndyFramework.IOBoardRx.ft_param', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2281,
  serialized_end=2382,
)


_DIOINDEX = _descriptor.Descriptor(
  name='DIOIndex',
  full_name='Nrmk.IndyFramework.DIOIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIOIndex.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2384,
  serialized_end=2412,
)


_DIODIGITALINPUT = _descriptor.Descriptor(
  name='DIODigitalInput',
  full_name='Nrmk.IndyFramework.DIODigitalInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIODigitalInput.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di_list', full_name='Nrmk.IndyFramework.DIODigitalInput.di_list', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2414,
  serialized_end=2466,
)


_DIODIGITALOUTPUT = _descriptor.Descriptor(
  name='DIODigitalOutput',
  full_name='Nrmk.IndyFramework.DIODigitalOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIODigitalOutput.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_list', full_name='Nrmk.IndyFramework.DIODigitalOutput.do_list', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2468,
  serialized_end=2521,
)


_SERVOPARAM = _descriptor.Descriptor(
  name='ServoParam',
  full_name='Nrmk.IndyFramework.ServoParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveIdx', full_name='Nrmk.IndyFramework.ServoParam.slaveIdx', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.ServoParam.val', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2523,
  serialized_end=2566,
)


_SDOINTVAL = _descriptor.Descriptor(
  name='SDOIntVal',
  full_name='Nrmk.IndyFramework.SDOIntVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOIntVal.val', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2568,
  serialized_end=2592,
)


_SDOFLOATVAL = _descriptor.Descriptor(
  name='SDOFloatVal',
  full_name='Nrmk.IndyFramework.SDOFloatVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOFloatVal.val', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2594,
  serialized_end=2620,
)


_SDOSTRVAL = _descriptor.Descriptor(
  name='SDOStrVal',
  full_name='Nrmk.IndyFramework.SDOStrVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOStrVal.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2622,
  serialized_end=2646,
)


_ETHERCATINFO = _descriptor.Descriptor(
  name='EtherCATInfo',
  full_name='Nrmk.IndyFramework.EtherCATInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2648,
  serialized_end=2662,
)


_ROBOTZEROCOUNT = _descriptor.Descriptor(
  name='RobotZeroCount',
  full_name='Nrmk.IndyFramework.RobotZeroCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='Nrmk.IndyFramework.RobotZeroCount.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2664,
  serialized_end=2695,
)

_SERVOTXINDEX.fields_by_name['tx'].message_type = _SERVOTX
_SERVORXINDEX.fields_by_name['rx'].message_type = _SERVORX
_SERVORXINDEXKEBA.fields_by_name['rx'].message_type = _SERVORXKEBA
_ENDTOOLTX.fields_by_name['ft_sensor'].message_type = _FTSENSOR
_IOBOARDTX.fields_by_name['ft_sensor'].message_type = _FTSENSOR
DESCRIPTOR.message_types_by_name['MasterStatus'] = _MASTERSTATUS
DESCRIPTOR.message_types_by_name['SlaveStatus'] = _SLAVESTATUS
DESCRIPTOR.message_types_by_name['EcatDomainStatus'] = _ECATDOMAINSTATUS
DESCRIPTOR.message_types_by_name['EcatSystemReady'] = _ECATSYSTEMREADY
DESCRIPTOR.message_types_by_name['EcatServoOn'] = _ECATSERVOON
DESCRIPTOR.message_types_by_name['SlaveTypeNum'] = _SLAVETYPENUM
DESCRIPTOR.message_types_by_name['ServoIndex'] = _SERVOINDEX
DESCRIPTOR.message_types_by_name['EcatIndex'] = _ECATINDEX
DESCRIPTOR.message_types_by_name['ServoTx'] = _SERVOTX
DESCRIPTOR.message_types_by_name['ServoRx'] = _SERVORX
DESCRIPTOR.message_types_by_name['ServoTxIndex'] = _SERVOTXINDEX
DESCRIPTOR.message_types_by_name['ServoRxIndex'] = _SERVORXINDEX
DESCRIPTOR.message_types_by_name['ServoTxKeba'] = _SERVOTXKEBA
DESCRIPTOR.message_types_by_name['ServoRxKeba'] = _SERVORXKEBA
DESCRIPTOR.message_types_by_name['ServoRxIndexKeba'] = _SERVORXINDEXKEBA
DESCRIPTOR.message_types_by_name['ServoTemp'] = _SERVOTEMP
DESCRIPTOR.message_types_by_name['ServoError'] = _SERVOERROR
DESCRIPTOR.message_types_by_name['ServoBrake'] = _SERVOBRAKE
DESCRIPTOR.message_types_by_name['FTSensor'] = _FTSENSOR
DESCRIPTOR.message_types_by_name['EndtoolTx'] = _ENDTOOLTX
DESCRIPTOR.message_types_by_name['EndtoolRx'] = _ENDTOOLRX
DESCRIPTOR.message_types_by_name['EndtoolDockingTx'] = _ENDTOOLDOCKINGTX
DESCRIPTOR.message_types_by_name['IOBoardTx'] = _IOBOARDTX
DESCRIPTOR.message_types_by_name['IOBoardRx'] = _IOBOARDRX
DESCRIPTOR.message_types_by_name['DIOIndex'] = _DIOINDEX
DESCRIPTOR.message_types_by_name['DIODigitalInput'] = _DIODIGITALINPUT
DESCRIPTOR.message_types_by_name['DIODigitalOutput'] = _DIODIGITALOUTPUT
DESCRIPTOR.message_types_by_name['ServoParam'] = _SERVOPARAM
DESCRIPTOR.message_types_by_name['SDOIntVal'] = _SDOINTVAL
DESCRIPTOR.message_types_by_name['SDOFloatVal'] = _SDOFLOATVAL
DESCRIPTOR.message_types_by_name['SDOStrVal'] = _SDOSTRVAL
DESCRIPTOR.message_types_by_name['EtherCATInfo'] = _ETHERCATINFO
DESCRIPTOR.message_types_by_name['RobotZeroCount'] = _ROBOTZEROCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MasterStatus = _reflection.GeneratedProtocolMessageType('MasterStatus', (_message.Message,), {
  'DESCRIPTOR' : _MASTERSTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MasterStatus)
  })
_sym_db.RegisterMessage(MasterStatus)

SlaveStatus = _reflection.GeneratedProtocolMessageType('SlaveStatus', (_message.Message,), {
  'DESCRIPTOR' : _SLAVESTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SlaveStatus)
  })
_sym_db.RegisterMessage(SlaveStatus)

EcatDomainStatus = _reflection.GeneratedProtocolMessageType('EcatDomainStatus', (_message.Message,), {
  'DESCRIPTOR' : _ECATDOMAINSTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatDomainStatus)
  })
_sym_db.RegisterMessage(EcatDomainStatus)

EcatSystemReady = _reflection.GeneratedProtocolMessageType('EcatSystemReady', (_message.Message,), {
  'DESCRIPTOR' : _ECATSYSTEMREADY,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatSystemReady)
  })
_sym_db.RegisterMessage(EcatSystemReady)

EcatServoOn = _reflection.GeneratedProtocolMessageType('EcatServoOn', (_message.Message,), {
  'DESCRIPTOR' : _ECATSERVOON,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatServoOn)
  })
_sym_db.RegisterMessage(EcatServoOn)

SlaveTypeNum = _reflection.GeneratedProtocolMessageType('SlaveTypeNum', (_message.Message,), {
  'DESCRIPTOR' : _SLAVETYPENUM,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SlaveTypeNum)
  })
_sym_db.RegisterMessage(SlaveTypeNum)

ServoIndex = _reflection.GeneratedProtocolMessageType('ServoIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVOINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoIndex)
  })
_sym_db.RegisterMessage(ServoIndex)

EcatIndex = _reflection.GeneratedProtocolMessageType('EcatIndex', (_message.Message,), {
  'DESCRIPTOR' : _ECATINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatIndex)
  })
_sym_db.RegisterMessage(EcatIndex)

ServoTx = _reflection.GeneratedProtocolMessageType('ServoTx', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTx)
  })
_sym_db.RegisterMessage(ServoTx)

ServoRx = _reflection.GeneratedProtocolMessageType('ServoRx', (_message.Message,), {
  'DESCRIPTOR' : _SERVORX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRx)
  })
_sym_db.RegisterMessage(ServoRx)

ServoTxIndex = _reflection.GeneratedProtocolMessageType('ServoTxIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTXINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTxIndex)
  })
_sym_db.RegisterMessage(ServoTxIndex)

ServoRxIndex = _reflection.GeneratedProtocolMessageType('ServoRxIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxIndex)
  })
_sym_db.RegisterMessage(ServoRxIndex)

ServoTxKeba = _reflection.GeneratedProtocolMessageType('ServoTxKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTxKeba)
  })
_sym_db.RegisterMessage(ServoTxKeba)

ServoRxKeba = _reflection.GeneratedProtocolMessageType('ServoRxKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxKeba)
  })
_sym_db.RegisterMessage(ServoRxKeba)

ServoRxIndexKeba = _reflection.GeneratedProtocolMessageType('ServoRxIndexKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXINDEXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxIndexKeba)
  })
_sym_db.RegisterMessage(ServoRxIndexKeba)

ServoTemp = _reflection.GeneratedProtocolMessageType('ServoTemp', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTEMP,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTemp)
  })
_sym_db.RegisterMessage(ServoTemp)

ServoError = _reflection.GeneratedProtocolMessageType('ServoError', (_message.Message,), {
  'DESCRIPTOR' : _SERVOERROR,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoError)
  })
_sym_db.RegisterMessage(ServoError)

ServoBrake = _reflection.GeneratedProtocolMessageType('ServoBrake', (_message.Message,), {
  'DESCRIPTOR' : _SERVOBRAKE,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoBrake)
  })
_sym_db.RegisterMessage(ServoBrake)

FTSensor = _reflection.GeneratedProtocolMessageType('FTSensor', (_message.Message,), {
  'DESCRIPTOR' : _FTSENSOR,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FTSensor)
  })
_sym_db.RegisterMessage(FTSensor)

EndtoolTx = _reflection.GeneratedProtocolMessageType('EndtoolTx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolTx)
  })
_sym_db.RegisterMessage(EndtoolTx)

EndtoolRx = _reflection.GeneratedProtocolMessageType('EndtoolRx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLRX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolRx)
  })
_sym_db.RegisterMessage(EndtoolRx)

EndtoolDockingTx = _reflection.GeneratedProtocolMessageType('EndtoolDockingTx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLDOCKINGTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolDockingTx)
  })
_sym_db.RegisterMessage(EndtoolDockingTx)

IOBoardTx = _reflection.GeneratedProtocolMessageType('IOBoardTx', (_message.Message,), {
  'DESCRIPTOR' : _IOBOARDTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOBoardTx)
  })
_sym_db.RegisterMessage(IOBoardTx)

IOBoardRx = _reflection.GeneratedProtocolMessageType('IOBoardRx', (_message.Message,), {
  'DESCRIPTOR' : _IOBOARDRX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOBoardRx)
  })
_sym_db.RegisterMessage(IOBoardRx)

DIOIndex = _reflection.GeneratedProtocolMessageType('DIOIndex', (_message.Message,), {
  'DESCRIPTOR' : _DIOINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIOIndex)
  })
_sym_db.RegisterMessage(DIOIndex)

DIODigitalInput = _reflection.GeneratedProtocolMessageType('DIODigitalInput', (_message.Message,), {
  'DESCRIPTOR' : _DIODIGITALINPUT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIODigitalInput)
  })
_sym_db.RegisterMessage(DIODigitalInput)

DIODigitalOutput = _reflection.GeneratedProtocolMessageType('DIODigitalOutput', (_message.Message,), {
  'DESCRIPTOR' : _DIODIGITALOUTPUT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIODigitalOutput)
  })
_sym_db.RegisterMessage(DIODigitalOutput)

ServoParam = _reflection.GeneratedProtocolMessageType('ServoParam', (_message.Message,), {
  'DESCRIPTOR' : _SERVOPARAM,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoParam)
  })
_sym_db.RegisterMessage(ServoParam)

SDOIntVal = _reflection.GeneratedProtocolMessageType('SDOIntVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOINTVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOIntVal)
  })
_sym_db.RegisterMessage(SDOIntVal)

SDOFloatVal = _reflection.GeneratedProtocolMessageType('SDOFloatVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOFLOATVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOFloatVal)
  })
_sym_db.RegisterMessage(SDOFloatVal)

SDOStrVal = _reflection.GeneratedProtocolMessageType('SDOStrVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOSTRVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOStrVal)
  })
_sym_db.RegisterMessage(SDOStrVal)

EtherCATInfo = _reflection.GeneratedProtocolMessageType('EtherCATInfo', (_message.Message,), {
  'DESCRIPTOR' : _ETHERCATINFO,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EtherCATInfo)
  })
_sym_db.RegisterMessage(EtherCATInfo)

RobotZeroCount = _reflection.GeneratedProtocolMessageType('RobotZeroCount', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTZEROCOUNT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.RobotZeroCount)
  })
_sym_db.RegisterMessage(RobotZeroCount)


# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages
import sys

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


if sys.version_info < (3, 9):
    install_requires = [
        "grpcio==1.39.0",
        "grpcio-tools==1.39.0",
        "protobuf==3.17.3",
        "requests==2.22.0",
        "Pillow==9.5.0",
        "numpy==1.21.6",
        "pyModbusTCP==0.2.1",
        "netifaces==0.11.0"
    ]
else:
    install_requires = [
        "grpcio",
        "grpcio-tools",
        "protobuf",
        "requests",
        "Pillow",
        "numpy",
        "pyModbusTCP",
        "netifaces"
    ]

setup(
    name="neuromeka",
    version="3.2.0.2",
    author="Neuromeka",
    author_email="youngjin.heo@neuromeka.com",
    description="Neuromeka client protocols for IndyDCP3, IndyEye, Moby, Ecat, and Motor",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/neuromeka-robotics/neuromeka-clients3",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10"
    ],
    python_requires=">=3.6",
    install_requires=install_requires,
)